@@ -20,10 +20,12 @@ public:
     QRegExp urlPattern() const;
     bool urlSupported(const QUrl &url) const;
     void checkUrl(const QUrl &url);
-    void getDownloadUrl(const QUrl &url);
+    void getDownloadRequest(const QUrl &url);
     inline bool loginSupported() const { return true; }
     void login(const QString &username, const QString &password);
     inline bool recaptchaRequired() const { return false; }
+    inline int maximumConnections() const { return m_connections; }
+    bool cancelCurrentOperation();
 
 private:
     void getDownloadLimitInfo(const QString &fileId);
@@ -39,11 +41,15 @@ private slots:
     void getDownloadLink();
     void checkDownloadLink();
 
+signals:
+    void currentOperationCancelled();
+
 private:
     QUrl m_downloadUrl;
     QTimer *m_waitTimer;
     int m_waitTime;
     int m_wait;
+    int m_connections;
 };
 
 #endif // FOURSHARED_H
